from enum import StrEnum
from maleo.types.string import ListOfStrs


class SuccessCode(StrEnum):
    ANY_DATA = "MAL-SCS-ADT-001"
    NO_DATA = "MAL-SCS-NDT-001"
    SINGLE_DATA = "MAL-SCS-SGD-001"
    CREATE_SINGLE_DATA = "MAL-SCS-SGD-002"
    READ_SINGLE_DATA = "MAL-SCS-SGD-003"
    UPDATE_SINGLE_DATA = "MAL-SCS-SGD-004"
    DELETE_SINGLE_DATA = "MAL-SCS-SGD-005"
    OPTIONAL_SINGLE_DATA = "MAL-SCS-OSD-001"
    MULTIPLE_DATA = "MAL-SCS-MTD-001"
    CREATE_MULTIPLE_DATA = "MAL-SCS-MTD-002"
    READ_MULTIPLE_DATA = "MAL-SCS-MTD-003"
    UPDATE_MULTIPLE_DATA = "MAL-SCS-MTD-004"
    DELETE_MULTIPLE_DATA = "MAL-SCS-MTD-005"
    OPTIONAL_MULTIPLE_DATA = "MAL-SCS-OMD-001"

    @classmethod
    def choices(cls) -> ListOfStrs:
        return [e.value for e in cls]
